@@ -24,6 +24,8 @@ from altscore.borrower_central.model.automations import AutomationsAsyncModule,
 from altscore.borrower_central.model.stages import StagesAsyncModule, StagesSyncModule
 from altscore.borrower_central.model.risk_ratings import RiskRatingsAsyncModule, RiskRatingsSyncModule
 from altscore.borrower_central.model.usecases import UsecasesAsyncModule, UsecasesSyncModule
+from altscore.borrower_central.model.metrics import MetricsAsyncModule, MetricsSyncModule
+from altscore.borrower_central.model.policy_policies import PolicyAsyncModule, PolicySyncModule
 
 
 class BorrowerCentralAsync:
@@ -34,6 +36,7 @@ class BorrowerCentralAsync:
         self.automations = AutomationsAsyncModule(altscore_client)
         self.borrowers = BorrowersAsyncModule(altscore_client)
         self.borrower_fields = BorrowerFieldsAsyncModule(altscore_client)
+        self.metrics = MetricsAsyncModule(altscore_client)
         self.data_models = DataModelAsyncModule(altscore_client)
         self.documents = DocumentsAsyncModule(altscore_client)
         self.stages = StagesAsyncModule(altscore_client)
@@ -53,6 +56,7 @@ class BorrowerCentralAsync:
         self.forms = FormsAsyncModule(altscore_client)
         self.alerts = AlertsAsyncModule(altscore_client)
         self.rules = RulesAsyncModule(altscore_client)
+        self.policies = PolicyAsyncModule(altscore_client)
         self.sat_integration = SatIntegrationAsyncModule(altscore_client)
         self.usecases = UsecasesAsyncModule(altscore_client)
 
@@ -65,6 +69,7 @@ class BorrowerCentralSync:
         self.automations = AutomationsSyncModule(altscore_client)
         self.borrowers = BorrowersSyncModule(altscore_client)
         self.borrower_fields = BorrowerFieldsSyncModule(altscore_client)
+        self.metrics = MetricsSyncModule(altscore_client)
         self.data_models = DataModelSyncModule(altscore_client)
         self.documents = DocumentsSyncModule(altscore_client)
         self.stages = StagesSyncModule(altscore_client)
@@ -84,5 +89,6 @@ class BorrowerCentralSync:
         self.forms = FormsSyncModule(altscore_client)
         self.alerts = AlertsSyncModule(altscore_client)
         self.rules = RulesSyncModule(altscore_client)
+        self.policies = PolicySyncModule(altscore_client)
         self.sat_integration = SatIntegrationSyncModule(altscore_client)
         self.usecases = UsecasesSyncModule(altscore_client)
