@@ -2,6 +2,7 @@ from altscore.cms.model.partners import PartnersSyncModule, PartnersAsyncModule
 from altscore.cms.model.clients import ClientsSyncModule, ClientsAsyncModule
 from altscore.cms.model.dpas import DPAFlowsAsyncModule, DPAFlowsSyncModule
 from altscore.cms.model.debts import DebtsAsyncModule, DebtsSyncModule
+from altscore.cms.model.payment_orders import PaymentOrdersAsyncModule, PaymentOrdersSyncModule
 from altscore.cms.helpers import build_headers
 
 
@@ -12,6 +13,7 @@ class CMSSync:
         self.partners = PartnersSyncModule(altscore_client)
         self.dpas = DPAFlowsSyncModule(altscore_client)
         self.debts = DebtsSyncModule(altscore_client)
+        self.payment_orders = PaymentOrdersSyncModule(altscore_client)
 
 
 class CMSAsync:
@@ -21,3 +23,4 @@ class CMSAsync:
         self.partners = PartnersAsyncModule(altscore_client)
         self.dpas = DPAFlowsAsyncModule(altscore_client)
         self.debts = DebtsAsyncModule(altscore_client)
+        self.payment_orders = PaymentOrdersAsyncModule(altscore_client)
